<h1 align="center">
    <br/>
    <a href="https://github.com/Diffylab/UniSerializer">
        <img src="UniSerializer.svg" alt="UniSerializer" width="400">
    </a>
    <br/>
    <br/>
</h1>

<h4 align="center">🔣🚀 Fast and efficient - It's a universal serializer, without schematics ! 🤗</h4>

## &#x1F4BE; Install

Download the latest version of UniSerializer from
the [GitHub releases](https://github.com/Diffylab/UniSerializer/releases) page.

### Python 3.x version
```
pip install uniserializer
```
or
```
cd python/
python setup.py install
```
## &#x1F4AC; How to Contribute

### Get the code

```
$ git clone https://github.com/Diffylab/UniSerializer.git
$ cd UniSerializer-master
```


## &#x00A9;&#xFE0F; License

MIT. Copyright (c) [Diffy Ltd](https://github.com/diffylab).
